@@ -1,3 +1,11 @@
+/*
+ * astime is an analogue clock utility for X Windows.
+ * Copyright (c) 1998-99  Albert Dorofeev <Albert@mail.dma.be>
+ * For the updates see http://bewoner.dma.be/Albert/linux/
+ *
+ * This software is distributed under GPL. For details see LICENSE
+ * file.
+ */
 #include <stdio.h>
 #include <stdlib.h>
 #include <math.h>
@@ -667,10 +675,19 @@ void initialize(
         SizeHints.flags |= PMinSize|PMaxSize;
 
 	/* Correct the offsets if the X/Y are negative */
-	if (x_negative)
+	SizeHints.win_gravity = NorthWestGravity;
+	if (x_negative) {
 		SizeHints.x -= state.total_size.x;
-	if (y_negative)
+		SizeHints.win_gravity = NorthEastGravity;
+	}
+	if (y_negative) {
 		SizeHints.y -= state.total_size.y;
+		if (x_negative)
+			SizeHints.win_gravity = SouthEastGravity;
+		else
+			SizeHints.win_gravity = SouthWestGravity;
+	}
+	SizeHints.flags |= PWinGravity;
 
         backgroundWindow = XCreatePixmap(
                 mainDisplay,
